==> qtjambi-remoteobjects-debuginfo-macos-6.6.0.jar: sources/QtJambiRemoteObjects/QRemoteObjectRegistryHost_shell.h <==
#ifndef QREMOTEOBJECTREGISTRYHOST_SHELL_H
#define QREMOTEOBJECTREGISTRYHOST_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectRegistryHost_shell : public QRemoteObjectRegistryHost, public QtJambiShellInterface
{
public:
    QRemoteObjectRegistryHost_shell(const QUrl& registryAddress0 = QUrl(), QObject* parent1 = nullptr);
    ~QRemoteObjectRegistryHost_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryUrl0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectRegistryHost_access : public QRemoteObjectRegistryHost
{
    jboolean __qt_setRegistryUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID registryUrl0);
};

#endif // QREMOTEOBJECTREGISTRYHOST_SHELL_H

==> qtjambi-remoteobjects-debuginfo-macos-6.7.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectRegistryHost_shell.h <==
#ifndef QREMOTEOBJECTREGISTRYHOST_SHELL_H
#define QREMOTEOBJECTREGISTRYHOST_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectRegistryHost_shell : public QRemoteObjectRegistryHost, public QtJambiShellInterface
{
public:
    QRemoteObjectRegistryHost_shell(const QUrl& registryAddress0 = QUrl(), QObject* parent1 = nullptr);
    ~QRemoteObjectRegistryHost_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QRemoteObjectRegistryHost_mshell;
    friend class QRemoteObjectRegistryHost_oshell;
};


class QRemoteObjectRegistryHost_mshell : public QRemoteObjectRegistryHost_shell
{
public:
    using QRemoteObjectRegistryHost_shell::QRemoteObjectRegistryHost_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QRemoteObjectRegistryHost_oshell : public QRemoteObjectRegistryHost_mshell
{
public:
    using QRemoteObjectRegistryHost_mshell::QRemoteObjectRegistryHost_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryUrl0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectRegistryHost_access : public QRemoteObjectRegistryHost
{
    jboolean __qt_setRegistryUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID registryUrl0);
};

#endif // QREMOTEOBJECTREGISTRYHOST_SHELL_H
